summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/umlobjectlist.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/umlobjectlist.h')
-rw-r--r--umbrello/umbrello/umlobjectlist.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/umbrello/umbrello/umlobjectlist.h b/umbrello/umbrello/umlobjectlist.h
index d9d11c83..f9d633c2 100644
--- a/umbrello/umbrello/umlobjectlist.h
+++ b/umbrello/umbrello/umlobjectlist.h
@@ -19,20 +19,20 @@
#ifndef UMLOBJECTLIST_H
#define UMLOBJECTLIST_H
-#include <qptrlist.h>
+#include <tqptrlist.h>
// forward declarations
class UMLObject;
-//typedef QPtrList<UMLObject> UMLObjectList;
-typedef QPtrListIterator<UMLObject> UMLObjectListIt;
+//typedef TQPtrList<UMLObject> UMLObjectList;
+typedef TQPtrListIterator<UMLObject> UMLObjectListIt;
/**
* This sub-class adds copyInto and clone to the QPtrList<UMLObject>
* base class.
*/
-class UMLObjectList : public QPtrList<UMLObject>
+class UMLObjectList : public TQPtrList<UMLObject>
{
public:
@@ -19,20 +19,20 @@
/**
- * This sub-class adds copyInto and clone to the QPtrList<UMLObject>
+ * This sub-class adds copyInto and clone to the TQPtrList<UMLObject>
* base class.
*/